.. pyMOD-OLED documentation master file, created by
   sphinx-quickstart on Thu Jun 18 08:32:52 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyMOD-OLED's documentation!
======================================

This module can be used for complete control on MOD-OLED-128x64. It uses

.. toctree::
    :maxdepth: 2

    API

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

